"""Helper functions

Consists of functions to typically be used within templates, but also
available to Controllers. This module is available to templates as 'h'.
"""
from webhelpers.html import literal
from webhelpers.html.tags import *
from webhelpers.pylonslib.secure_form import secure_form
from webhelpers.pylonslib import Flash as _Flash
from pylons import url

flash = _Flash()
